@@ -6,12 +6,16 @@ import os
 from docx2python import docx2python
 from pathlib import Path
 import regex
+import re
 
 import pandas as pd
 import numpy as np
 
-from . import regex_dictionary
-    
+from .regex_dictionary import get_chapter_beg_end
+from .regex_dictionary import get_chapter_regex
+from .regex_dictionary import get_section_beg_end
+from .regex_dictionary import get_section_regex
+
 class Contract:
     def __init__(self, path):
         self.path = path
@@ -25,17 +29,23 @@ class Contract:
                         self.full_text += para
         self.tg = regex.search('̩||||㷢|ͨ|||ƽ|', path).group()
 
-    # def get_front_page(self):
+    def get_front_page(self):
+        firstpages = {"":25,"ƽ":25,"":28,"ͨ":18,"":22,"":19,"㷢":0,"":25,"":28,"̩":23}
+        return firstpages[self.tg]
 
-    # def get_risk_level(self):
+    def get_risk_level(self):
+        try:
+            return re.search("R[0-9]",re.search("[^]+ϸͶ", self.full_text).group()).group()
+        except:
+            return ""
 
     def get_full_text(self):
         return self.full_text
 
     def get_chapter(self, chapter): #works
-        beg_chapter_name = regex_dictionary.get_chapter_beg_end(self.tg, chapter)[0][0]
-        end_chapter_name = regex_dictionary.get_chapter_beg_end(self.tg, chapter)[0][1]
-        chapter_regex = regex_dictionary.get_chapter_regex(self.tg, beg_chapter_name, end_chapter_name)
+        beg_chapter_name = get_chapter_beg_end(self.tg, chapter)[0][0]
+        end_chapter_name = get_chapter_beg_end(self.tg, chapter)[0][1]
+        chapter_regex = get_chapter_regex(self.tg, beg_chapter_name, end_chapter_name)
         try:
             self.chapter = regex.search(chapter_regex, self.full_text).group()
         except:
@@ -45,9 +55,9 @@ class Contract:
 
     def get_section_of_chapter(self, chapter, section):
         chapter = self.get_chapter(chapter)
-        beg_section_name = regex_dictionary.get_section_beg_end(self.tg, section)[0][0]
-        end_section_name = regex_dictionary.get_section_beg_end(self.tg, section)[0][1]
-        section_regex = regex_dictionary.get_section_regex(self.tg, beg_section_name, end_section_name)
+        beg_section_name = get_section_beg_end(self.tg, section)[0][0]
+        end_section_name = get_section_beg_end(self.tg, section)[0][1]
+        section_regex = get_section_regex(self.tg, beg_section_name, end_section_name)
         try:
             self.section = regex.search(section_regex, chapter).group()
             if self.section[0] == '':
@@ -57,7 +67,7 @@ class Contract:
         finally:
             return self.section
 
-    # def to_pdf(): under construnction, same as Contracts method, but only exports pdf of one contract document
+    # def to_pdf(): #under construnction, same as Contracts method, but only exports pdf of one contract document
 
 class Contracts:
     def __init__(self, folder_path):
@@ -83,7 +93,7 @@ class Contracts:
         for file_path in self.all_files:
             contract = Contract(file_path)
             if contract.tg!='㷢': out[contract.product_name] = [contract.get_section_of_chapter(chapter_name, section_name).replace('\t', ' ').replace('\n', '') for section_name in section_names]
-        return out, sections
+        return out, section_names
         
     def get_df(self, dict):
         data = dict[0]
@@ -100,11 +110,16 @@ class Contracts:
 
     # def to_pdf(self, regex): under construction, to include functions from strategy_extract to export pdf of only regexed contents
 
+in_path = sys.argv[1]
+out_path = sys.argv[2]
+chapter = sys.argv[3]
+sections = list(sys.argv[4:])
+
+def main():
+    contracts = Contracts(in_path)
+    contracts.to_excel(contracts.get_df(contracts.get_sections(chapter, sections)), out_path) # works
+
 if __name__=='__main__':
-    in_path = sys.argv[1]
-    out_path = sys.argv[2]
-    chapter = sys.argv[3]
-    sections = list(sys.argv[4:])
 
     ### single contract class
     # contract = Contract('/Users/andy/Desktop/work/ubiquant/ͬȡ/ҳͶʲȡ//׾ѡ2˽ļ֤ȯͶʻͬйܰ-ݵһβЭ£Ͷʶ˺£V1.2.8TX-20210302壩.docx')
@@ -112,5 +127,5 @@ if __name__=='__main__':
     # print(contract.get_section_of_chapter('Ͷ','Ͷ'))
 
     ### folder of contracts class
-    contracts = Contracts(in_path)
-    contracts.to_excel(contracts.get_df(contracts.get_sections(chapter, sections)), out_path) # works
\ No newline at end of file
+    
+    main()
\ No newline at end of file
